@@ -38,11 +38,12 @@ namespace KTextEditor
 class AnnotationModel;
 class Message;
 class InlineNoteProvider;
+class DocumentPrivate;
 }
 
-namespace KTextEditor
+namespace Kate
 {
-class DocumentPrivate;
+class TextCursor;
 }
 class KateBookmarks;
 class KateViewConfig;
@@ -64,6 +65,7 @@ class KateAbstractInputMode;
 class KateScriptActionMenu;
 class KateMessageLayout;
 class KateInlineNoteData;
+class MulticursorTest;
 
 class KToggleAction;
 class KSelectAction;
@@ -95,6 +97,7 @@ class KTEXTEDITOR_EXPORT ViewPrivate final : public KTextEditor::View,
     friend class ::KateViewInternal;
     friend class ::KateIconBorder;
     friend class ::KateTextPreview;
+    friend MulticursorTest;
 
 public:
     ViewPrivate(KTextEditor::DocumentPrivate *doc, QWidget *parent, KTextEditor::MainWindow *mainWindow = nullptr);
@@ -116,7 +119,7 @@ public:
     InputMode viewInputMode() const override;
     QString viewInputModeHuman() const override;
 
-    void setInputMode(InputMode mode);
+    void setInputMode(InputMode mode, const bool rememberInConfig = true);
 
 public:
     KateViewInternal *getViewInternal()
@@ -193,6 +196,72 @@ public:
     bool mouseTrackingEnabled() const override;
     bool setMouseTrackingEnabled(bool enable) override;
 
+    /*
+     * multicursor stuff
+     */
+
+    // Helper structs to work with multicursors
+    struct PlainSecondaryCursor {
+        KTextEditor::Cursor pos;
+        KTextEditor::Range range;
+        friend bool operator<(const PlainSecondaryCursor &l, const PlainSecondaryCursor &r)
+        {
+            return l.pos < r.pos;
+        }
+    };
+    struct SecondaryCursor {
+        std::unique_ptr<Kate::TextCursor> pos;
+        std::unique_ptr<Kate::TextRange> range;
+        KTextEditor::Cursor anchor = KTextEditor::Cursor::invalid();
+
+        KTextEditor::Cursor cursor() const
+        {
+            return pos->toCursor();
+        }
+
+        friend bool operator<(const SecondaryCursor &l, const SecondaryCursor &r)
+        {
+            return l.cursor() < r.cursor();
+        }
+
+        friend bool operator<(const SecondaryCursor &l, const KTextEditor::Cursor &r)
+        {
+            return l.cursor() < r;
+        }
+
+        friend bool operator==(const SecondaryCursor &l, const SecondaryCursor &r)
+        {
+            return l.cursor() == r.cursor();
+        }
+    };
+
+    // Just a helper to control the states in which we disallow multicursor
+    bool isMulticursorNotAllowed() const;
+
+    // Adds a secondary cursor
+    bool addSecondaryCursorAt(const KTextEditor::Cursor &cursor, bool toggle = true);
+    void setSecondaryCursors(const QVector<KTextEditor::Cursor> &positions);
+
+    const std::vector<SecondaryCursor> &secondaryCursors() const;
+    QVector<PlainSecondaryCursor> plainSecondaryCursors() const;
+    void addSecondaryCursorsWithSelection(const QVector<PlainSecondaryCursor> &cursorsWithSelection);
+
+    void clearSecondaryCursors();
+    void clearSecondarySelections();
+
+    // Check all the cursors, and remove cursors which have the same positions
+    // if @p matchLine is true, cursors whose line are same will be considered equal
+    void ensureUniqueCursors(bool matchLine = false);
+
+private:
+    void removeSecondaryCursors(const std::vector<KTextEditor::Cursor> &cursorToRemove);
+    Kate::TextRange *newSecondarySelectionRange(KTextEditor::Range);
+
+    std::vector<SecondaryCursor> m_secondaryCursors;
+
+    void addSecondaryCursorDown();
+    void addSecondaryCursorUp();
+
 private:
     void notifyMousePositionChanged(const KTextEditor::Cursor newPosition);
 
@@ -451,7 +520,7 @@ public:
     */
     bool isOverwriteMode() const;
 
-    QString currentTextLine();
+    bool isLineRTL(int line) const;
 
     QTextLayout *textLayout(int line) const;
     QTextLayout *textLayout(const KTextEditor::Cursor pos) const;
@@ -521,6 +590,10 @@ public Q_SLOTS:
      */
     void noIndentNewline();
 
+    void newLineAbove();
+
+    void newLineBelow();
+
     /**
      * Insert a tabulator char at current cursor position.
      */
@@ -637,10 +710,13 @@ public Q_SLOTS:
     void find();
     void findSelectedForwards();
     void findSelectedBackwards();
+    void findNextOccurunceAndSelect();
+    void findAllOccuruncesAndSelect();
     void replace();
     void findNext();
     void findPrevious();
     void showSearchWrappedHint(bool isReverseSearch);
+    void createMultiCursorsFromSelection();
 
     void setFoldingMarkersOn(bool enable); // Not in KTextEditor::View, but should be
     void setIconBorder(bool enable);
@@ -706,6 +782,7 @@ public Q_SLOTS:
     void switchToCmdLine();
     void slotReadWriteChanged();
     void slotClipboardHistoryChanged();
+    void toggleCamelCaseCursor();
 
 Q_SIGNALS:
     void dropEventPass(QDropEvent *);
